@@ -10,8 +10,8 @@ import (
 func TestRoleRender(t *testing.T) {
 	c := render.Role{}
 	r := render.NewRow(3)
-	c.Render(load(t, "ro"), "", &r)
 
+	assert.NoError(t, c.Render(load(t, "ro"), "", &r))
 	assert.Equal(t, "default/blee", r.ID)
 	assert.Equal(t, render.Fields{"default", "blee"}, r.Fields[:2])
 }
